# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/asto',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/asto',
                'lib_path': 'asto'},
  'syms': { 'asto.arng': { 'asto.arng._safe_idx': ('arng.html#_safe_idx', 'asto/arng.py'),
                           'asto.arng._safe_len': ('arng.html#_safe_len', 'asto/arng.py'),
                           'asto.arng.arange': ('arng.html#arange', 'asto/arng.py'),
                           'asto.arng.arngchain': ('arng.html#arngchain', 'asto/arng.py'),
                           'asto.arng.arr2arng': ('arng.html#arr2arng', 'asto/arng.py'),
                           'asto.arng.asarng': ('arng.html#asarng', 'asto/arng.py'),
                           'asto.arng.df2arng': ('arng.html#df2arng', 'asto/arng.py'),
                           'asto.arng.isarng': ('arng.html#isarng', 'asto/arng.py'),
                           'asto.arng.try2arng': ('arng.html#try2arng', 'asto/arng.py')},
            'asto.arrs': { 'asto.arrs.ann2arr': ('arrs.html#ann2arr', 'asto/arrs.py'),
                           'asto.arrs.arrchain': ('arrs.html#arrchain', 'asto/arrs.py'),
                           'asto.arrs.as01': ('arrs.html#as01', 'asto/arrs.py'),
                           'asto.arrs.asarr': ('arrs.html#asarr', 'asto/arrs.py'),
                           'asto.arrs.chain': ('arrs.html#chain', 'asto/arrs.py'),
                           'asto.arrs.clone': ('arrs.html#clone', 'asto/arrs.py'),
                           'asto.arrs.cpu': ('arrs.html#cpu', 'asto/arrs.py'),
                           'asto.arrs.detach': ('arrs.html#detach', 'asto/arrs.py'),
                           'asto.arrs.dns2arr': ('arrs.html#dns2arr', 'asto/arrs.py'),
                           'asto.arrs.mth2arr': ('arrs.html#mth2arr', 'asto/arrs.py'),
                           'asto.arrs.mtx2arr': ('arrs.html#mtx2arr', 'asto/arrs.py'),
                           'asto.arrs.nparray': ('arrs.html#nparray', 'asto/arrs.py'),
                           'asto.arrs.numpy': ('arrs.html#numpy', 'asto/arrs.py'),
                           'asto.arrs.spr2arr': ('arrs.html#spr2arr', 'asto/arrs.py'),
                           'asto.arrs.toarray': ('arrs.html#toarray', 'asto/arrs.py'),
                           'asto.arrs.todense': ('arrs.html#todense', 'asto/arrs.py'),
                           'asto.arrs.tolist': ('arrs.html#tolist', 'asto/arrs.py'),
                           'asto.arrs.trc2arr': ('arrs.html#trc2arr', 'asto/arrs.py'),
                           'asto.arrs.try2arr': ('arrs.html#try2arr', 'asto/arrs.py')},
            'asto.cast': {'asto.cast.cast': ('cast.html#cast', 'asto/cast.py'), 'asto.cast.caster': ('cast.html#caster', 'asto/cast.py')},
            'asto.dict': {},
            'asto.nums': { 'asto.nums.ascomplex': ('nums.html#ascomplex', 'asto/nums.py'),
                           'asto.nums.asfloat': ('nums.html#asfloat', 'asto/nums.py'),
                           'asto.nums.asint': ('nums.html#asint', 'asto/nums.py'),
                           'asto.nums.asnum': ('nums.html#asnum', 'asto/nums.py')},
            'asto.sets': { 'asto.sets.any2set': ('sets.html#any2set', 'asto/sets.py'),
                           'asto.sets.asset': ('sets.html#asset', 'asto/sets.py'),
                           'asto.sets.setchain': ('sets.html#setchain', 'asto/sets.py'),
                           'asto.sets.try2set': ('sets.html#try2set', 'asto/sets.py')},
            'asto.slcs': { 'asto.slcs.asslc': ('slcs.html#asslc', 'asto/slcs.py'),
                           'asto.slcs.safeslice': ('slcs.html#safeslice', 'asto/slcs.py'),
                           'asto.slcs.slcchain': ('slcs.html#slcchain', 'asto/slcs.py'),
                           'asto.slcs.slice2list': ('slcs.html#slice2list', 'asto/slcs.py'),
                           'asto.slcs.try2slc': ('slcs.html#try2slc', 'asto/slcs.py')},
            'asto.tens': { 'asto.tens.asdev': ('tens.html#asdev', 'asto/tens.py'),
                           'asto.tens.asten': ('tens.html#asten', 'asto/tens.py'),
                           'asto.tens.devchain': ('tens.html#devchain', 'asto/tens.py'),
                           'asto.tens.dtypechain': ('tens.html#dtypechain', 'asto/tens.py'),
                           'asto.tens.has_mps': ('tens.html#has_mps', 'asto/tens.py'),
                           'asto.tens.mpsdtype': ('tens.html#mpsdtype', 'asto/tens.py'),
                           'asto.tens.ten2cpu': ('tens.html#ten2cpu', 'asto/tens.py'),
                           'asto.tens.ten2cuda': ('tens.html#ten2cuda', 'asto/tens.py'),
                           'asto.tens.ten2mps': ('tens.html#ten2mps', 'asto/tens.py'),
                           'asto.tens.tenchain': ('tens.html#tenchain', 'asto/tens.py'),
                           'asto.tens.to': ('tens.html#to', 'asto/tens.py'),
                           'asto.tens.try2dev': ('tens.html#try2dev', 'asto/tens.py'),
                           'asto.tens.try2dtype': ('tens.html#try2dtype', 'asto/tens.py'),
                           'asto.tens.try2ten': ('tens.html#try2ten', 'asto/tens.py')},
            'asto.time': { 'asto.time.day2hours': ('time.html#day2hours', 'asto/time.py'),
                           'asto.time.day2hrs': ('time.html#day2hrs', 'asto/time.py')}}}
