# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_dict.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/04_dict.ipynb 6
#| export


# %% ../nbs/04_dict.ipynb 8
from typing import Any, Union, TypeAlias, ParamSpec

# %% ../nbs/04_dict.ipynb 10
#| export


# %% ../nbs/04_dict.ipynb 12
#| export


# %% ../nbs/04_dict.ipynb 14
#| export


# %% ../nbs/04_dict.ipynb 16
#| export
