# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_time.ipynb.

# %% auto 0
__all__ = ['day2hrs', 'day2hours']

# %% ../nbs/02_time.ipynb 6
from datetime import date, datetime

# %% ../nbs/02_time.ipynb 8
from typing import Any, Union, TypeAlias, ParamSpec

# %% ../nbs/02_time.ipynb 10
#| export


# %% ../nbs/02_time.ipynb 12
#| export


# %% ../nbs/02_time.ipynb 14
#| export


# %% ../nbs/02_time.ipynb 16
def day2hrs(day: int) -> int:
    '''Convert days to hours
    
    See Also
    --------
    day2hours : Alias of `day2hrs`
    '''
    return int(day * 24)

def day2hours(day: int) -> int:
    '''Convert days to hours
    
    See Also
    --------
    day2hrs : Alias of `day2hours`
    '''
    return day2hrs(day)
