__version__ = "0.0.16"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00__init__.ipynb 3
import itertools
from importlib import import_module
from types import ModuleType

def loadmod(mod: ModuleType):
    if hasattr(mod, '__all__'): return mod.__all__
    if hasattr(mod, '__module__'): return loadmod(import_module(mod.__module__))
    raise AttributeError(f"module {mod} has no attribute '__all__'")

# %% ../nbs/00__init__.ipynb 4
from asto import (
    cast, arrs, time, nums, dict, arng, slcs, tens, sets
)

from .cast import *
from .arrs import *
from .time import *
from .nums import *
from .dict import *
from .arng import *
from .slcs import *
from .tens import *
from .sets import *

# %% ../nbs/00__init__.ipynb 5
__all__ = sorted(set(itertools.chain(*[
    loadmod(mod) for mod in (cast, arrs, time, nums, dict, arng, slcs, tens, sets)
])))
